@@ -37,10 +37,11 @@ void Dome::setDome(ISD::GDInterface *newDome)
     currentDome->disconnect(this);
 
     connect(currentDome, &ISD::Dome::newStatus, this, &Dome::newStatus);
-    connect(currentDome, &ISD::Dome::newParkStatus, this, &Dome::newParkStatus);
+    connect(currentDome, &ISD::Dome::newStatus, this, &Dome::setStatus);
     connect(currentDome, &ISD::Dome::newParkStatus, [&](ISD::ParkStatus status)
     {
         m_ParkStatus = status;
+        emit newParkStatus(status);
     });
     connect(currentDome, &ISD::Dome::newShutterStatus, this, &Dome::newShutterStatus);
     connect(currentDome, &ISD::Dome::newShutterStatus, [&](ISD::Dome::ShutterStatus status)
@@ -53,22 +54,6 @@ void Dome::setDome(ISD::GDInterface *newDome)
     connect(currentDome, &ISD::Dome::Disconnected, this, &Dome::disconnected);
 }
 
-//void Dome::setTelescope(ISD::GDInterface *newTelescope)
-//{
-//    if (currentDome == nullptr)
-//        return;
-
-//    ITextVectorProperty *activeDevices = currentDome->getBaseDevice()->getText("ACTIVE_DEVICES");
-//    if (activeDevices)
-//    {
-//        IText *activeTelescope = IUFindText(activeDevices, "ACTIVE_TELESCOPE");
-//        if (activeTelescope)
-//        {
-//            IUSaveText(activeTelescope, newTelescope->getDeviceName());
-//            currentDome->getDriverInfo()->getClientManager()->sendNewText(activeDevices);
-//        }
-//    }
-//}
 
 bool Dome::canPark()
 {
@@ -110,6 +95,12 @@ bool Dome::isMoving()
     return currentDome->isMoving();
 }
 
+bool Dome::isRolloffRoof()
+{
+    // a rolloff roof is a dome that can move neither absolutely nor relatively
+    return (currentDome && !currentDome->canAbsMove() && !currentDome->canRelMove());
+}
+
 bool Dome::canAbsoluteMove()
 {
     if (currentDome)
@@ -145,6 +136,15 @@ void Dome::setRelativePosition(double position)
         currentDome->setRelativePosition(position);
 }
 
+bool Dome::moveDome(bool moveCW, bool start)
+{
+    if (currentDome == nullptr)
+        return false;
+
+    return currentDome->moveDome(moveCW ? ISD::Dome::DOME_CW : ISD::Dome::DOME_CCW,
+                                 start  ? ISD::Dome::MOTION_START : ISD::Dome::MOTION_STOP);
+}
+
 bool Dome::isAutoSync()
 {
     if (currentDome)
@@ -178,42 +178,6 @@ bool Dome::controlShutter(bool open)
     return false;
 }
 
-#if 0
-Dome::ParkingStatus Dome::getParkingStatus()
-{
-    if (currentDome == nullptr || currentDome->canPark() == false)
-        return PARKING_ERROR;
-
-    ISwitchVectorProperty *parkSP = currentDome->getBaseDevice()->getSwitch("DOME_PARK");
-
-    if (parkSP == nullptr)
-        return PARKING_ERROR;
-
-    switch (parkSP->s)
-    {
-        case IPS_IDLE:
-            return PARKING_IDLE;
-
-        case IPS_OK:
-            if (parkSP->sp[0].s == ISS_ON)
-                return PARKING_OK;
-            else
-                return UNPARKING_OK;
-
-        case IPS_BUSY:
-            if (parkSP->sp[0].s == ISS_ON)
-                return PARKING_BUSY;
-            else
-                return UNPARKING_BUSY;
-
-        case IPS_ALERT:
-            return PARKING_ERROR;
-    }
-
-    return PARKING_ERROR;
-}
-#endif
-
 void Dome::removeDevice(ISD::GDInterface *device)
 {
     device->disconnect(this);
@@ -223,4 +187,25 @@ void Dome::removeDevice(ISD::GDInterface *device)
     }
 }
 
+void Dome::setStatus(ISD::Dome::Status status)
+{
+    // special case for rolloff roofs.
+    if (isRolloffRoof())
+    {
+        // if a parked rollof roof starts to move, its state changes to unparking
+        if (status == ISD::Dome::DOME_MOVING_CW && (m_ParkStatus == ISD::PARK_PARKED || m_ParkStatus == ISD::PARK_PARKING))
+        {
+            m_ParkStatus = ISD::PARK_UNPARKING;
+            emit newParkStatus(m_ParkStatus);
+        }
+        // if a unparked rollof roof starts to move, its state changes to parking
+        else if (status == ISD::Dome::DOME_MOVING_CCW && (m_ParkStatus == ISD::PARK_UNPARKED || m_ParkStatus == ISD::PARK_UNPARKING))
+        {
+            m_ParkStatus = ISD::PARK_PARKING;
+            emit newParkStatus(m_ParkStatus);
+        }
+    }
+    // in all other cases, do nothing
+}
+
 }
