@@ -20,6 +20,7 @@ void ObservatoryDomeModel::initModel(Dome *dome)
     connect(domeInterface, &Dome::ready, this, &ObservatoryDomeModel::ready);
     connect(domeInterface, &Dome::disconnected, this, &ObservatoryDomeModel::disconnected);
     connect(domeInterface, &Dome::newStatus, this, &ObservatoryDomeModel::newStatus);
+    connect(domeInterface, &Dome::newParkStatus, this, &ObservatoryDomeModel::newParkStatus);
     connect(domeInterface, &Dome::newShutterStatus, this, &ObservatoryDomeModel::newShutterStatus);
     connect(domeInterface, &Dome::azimuthPositionChanged, this, &ObservatoryDomeModel::azimuthPositionChanged);
     connect(domeInterface, &Dome::newAutoSyncStatus, this, &ObservatoryDomeModel::newAutoSyncStatus);
@@ -61,6 +62,23 @@ void ObservatoryDomeModel::unpark()
     domeInterface->unpark();
 }
 
+ISD::ParkStatus ObservatoryDomeModel::parkStatus()
+{
+    if (domeInterface == nullptr)
+        return ISD::PARK_UNKNOWN;
+    else if (isRolloffRoof())
+    {
+        // we need to override the parking status of the dome interface for opening and closing rolloff roofs
+        if (domeInterface->status() == ISD::Dome::DOME_MOVING_CW)
+            return ISD::PARK_UNPARKING;
+        else if (domeInterface->status() == ISD::Dome::DOME_MOVING_CCW)
+            return ISD::PARK_PARKING;
+    }
+
+    // in all other cases use the underlying park status
+    return domeInterface->parkStatus();
+}
+
 void ObservatoryDomeModel::setAutoSync(bool activate)
 {
     if (domeInterface == nullptr)
@@ -98,6 +116,15 @@ void ObservatoryDomeModel::closeShutter()
     domeInterface->controlShutter(false);
 }
 
+bool ObservatoryDomeModel::moveDome(bool moveCW, bool start)
+{
+    if (domeInterface == nullptr)
+        return false;
+
+    emit newLog(i18n("%2 dome motion %1...", moveCW ? "clockwise" : "counter clockwise", start ? "Starting" : "Stopping"));
+    return domeInterface->moveDome(moveCW, start);
+}
+
 void ObservatoryDomeModel::execute(WeatherActions actions)
 {
     if (hasShutter() && actions.closeShutter)
