@@ -812,12 +812,7 @@ CCD::CCD(GDInterface *iPtr) : DeviceDecorator(iPtr)
     m_Media.reset(new WSMedia(this));
     connect(m_Media.get(), &WSMedia::newFile, this, &CCD::setWSBLOB);
 
-    connect(clientManager, &ClientManager::newBLOBManager, [&](const char *device, INDI::Property * prop)
-    {
-        if (!strcmp(device, getDeviceName()))
-            emit newBLOBManager(prop);
-    });
-
+    connect(clientManager, &ClientManager::newBLOBManager, this, &CCD::setBLOBManager, Qt::UniqueConnection);
     m_LastNotificationTS = QDateTime::currentDateTime();
 }
 
@@ -827,6 +822,12 @@ CCD::~CCD()
         m_ImageViewerWindow->close();
 }
 
+void CCD::setBLOBManager(const char *device, INDI::Property *prop)
+{
+    if (!strcmp(device, getDeviceName()))
+        emit newBLOBManager(prop);
+}
+
 void CCD::registerProperty(INDI::Property *prop)
 {
     if (isConnected())
@@ -1456,6 +1457,8 @@ void CCD::processBLOB(IBLOB *bp)
                 m_ImageViewerWindow = new ImageViewer(getDeviceName(), KStars::Instance());
 
             m_ImageViewerWindow->loadImage(filename);
+
+            emit previewJPEGGenerated(filename, m_ImageViewerWindow->metadata());
         }
     }
     // Unless we have cfitsio, we're done.
